@@ -1,5 +1,70 @@
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+# ***********************************************************************
+# ******************  CANADIAN ASTRONOMY DATA CENTRE  *******************
+# *************  CENTRE CANADIEN DE DONNÉES ASTRONOMIQUES  **************
+#
+#  (c) 2022.                            (c) 2022.
+#  Government of Canada                 Gouvernement du Canada
+#  National Research Council            Conseil national de recherches
+#  Ottawa, Canada, K1A 0R6              Ottawa, Canada, K1A 0R6
+#  All rights reserved                  Tous droits réservés
+#
+#  NRC disclaims any warranties,        Le CNRC dénie toute garantie
+#  expressed, implied, or               énoncée, implicite ou légale,
+#  statutory, of any kind with          de quelque nature que ce
+#  respect to the software,             soit, concernant le logiciel,
+#  including without limitation         y compris sans restriction
+#  any warranty of merchantability      toute garantie de valeur
+#  or fitness for a particular          marchande ou de pertinence
+#  purpose. NRC shall not be            pour un usage particulier.
+#  liable in any event for any          Le CNRC ne pourra en aucun cas
+#  damages, whether direct or           être tenu responsable de tout
+#  indirect, special or general,        dommage, direct ou indirect,
+#  consequential or incidental,         particulier ou général,
+#  arising from the use of the          accessoire ou fortuit, résultant
+#  software.  Neither the name          de l'utilisation du logiciel. Ni
+#  of the National Research             le nom du Conseil National de
+#  Council of Canada nor the            Recherches du Canada ni les noms
+#  names of its contributors may        de ses  participants ne peuvent
+#  be used to endorse or promote        être utilisés pour approuver ou
+#  products derived from this           promouvoir les produits dérivés
+#  software without specific prior      de ce logiciel sans autorisation
+#  written permission.                  préalable et particulière
+#                                       par écrit.
+#
+#  This file is part of the             Ce fichier fait partie du projet
+#  OpenCADC project.                    OpenCADC.
+#
+#  OpenCADC is free software:           OpenCADC est un logiciel libre ;
+#  you can redistribute it and/or       vous pouvez le redistribuer ou le
+#  modify it under the terms of         modifier suivant les termes de
+#  the GNU Affero General Public        la “GNU Affero General Public
+#  License as published by the          License” telle que publiée
+#  Free Software Foundation,            par la Free Software Foundation
+#  either version 3 of the              : soit la version 3 de cette
+#  License, or (at your option)         licence, soit (à votre gré)
+#  any later version.                   toute version ultérieure.
+#
+#  OpenCADC is distributed in the       OpenCADC est distribué
+#  hope that it will be useful,         dans l’espoir qu’il vous
+#  but WITHOUT ANY WARRANTY;            sera utile, mais SANS AUCUNE
+#  without even the implied             GARANTIE : sans même la garantie
+#  warranty of MERCHANTABILITY          implicite de COMMERCIALISABILITÉ
+#  or FITNESS FOR A PARTICULAR          ni d’ADÉQUATION À UN OBJECTIF
+#  PURPOSE.  See the GNU Affero         PARTICULIER. Consultez la Licence
+#  General Public License for           Générale Publique GNU Affero
+#  more details.                        pour plus de détails.
+#
+#  You should have received             Vous devriez avoir reçu une
+#  a copy of the GNU Affero             copie de la Licence Générale
+#  General Public License along         Publique GNU Affero avec
+#  with OpenCADC.  If not, see          OpenCADC ; si ce n’est
+#  <http://www.gnu.org/licenses/>.      pas le cas, consultez :
+#                                       <http://www.gnu.org/licenses/>.
+#
+#  $Revision: 4 $
+#
+# ***********************************************************************
+#
 
 import os
 import sys
@@ -66,18 +131,20 @@ def compute_md5(filename):
     return md5
 
 
-def get_client(certfile, token):
+def get_client(certfile, token, insecure):
     """
     Returns a VOS client instance for each thread. VOS Client uses requests
     session which is not thread safe hence creating one instance of this class
     for each thread
     :param certfile:
     :param token:
+    :param insecure: do not check server SSL certs
     :return: vos.Client
     """
     if not hasattr(thread_local, "client"):
         thread_local.client = vos.Client(vospace_certfile=certfile,
-                                         vospace_token=token)
+                                         vospace_token=token,
+                                         insecure=insecure)
     return thread_local.client
 
 
@@ -113,7 +180,7 @@ def execute(src, dest, opt):
     stat = os.stat(src)
     if not opt.ignore_checksum and not opt.overwrite:
         src_md5 = compute_md5(src)
-    client = get_client(opt.certfile, opt.token)
+    client = get_client(opt.certfile, opt.token, opt.insecure)
     if not opt.overwrite:
         # Check if the file is the same
         try:
@@ -342,7 +409,8 @@ def vsync():
     destination = opt.destination
     try:
         client = vos.Client(
-            vospace_certfile=opt.certfile, vospace_token=opt.token)
+            vospace_certfile=opt.certfile, vospace_token=opt.token,
+            insecure=opt.insecure)
         if not client.is_remote_file(destination):
             parser.error("Only allows sync FROM local copy TO VOSpace")
         # Currently we don't create nodes in sync and we don't sync onto files
